@@ -4,6 +4,7 @@ from IPython.display import clear_output
 import concurrent.futures as cf
 import os
 import cv2 as cv
+import pkg_resources
 
 #Multiple of these functions takes an optional argument defining in which axis
 #the function operates. If 's' is passed as an argument, the operation is performed
@@ -93,7 +94,7 @@ def flatten(data_cube):
 
 #Reshapes flattened data cube back into 3 dimensions
 def inflate(array_2D, n_rows, n_cols):
-    return np.reshape(array_2D, [n_rows, n_cols, matrix.shape[1]])
+    return np.reshape(array_2D, [n_rows, n_cols, array_2D.shape[1]])
 
 #Median filters each band in data cube
 def median_filter_cube(data_cube, kernel_size):
@@ -122,11 +123,11 @@ def targeted_median_filter(input_array, px_idx, kernel_size):
 
 #Imports cube based on directory argument
 def load_cube(directory):
-    NoB = sum([ '.ppm' in s for s in os.listdir(f'{directory}images/capture')])
+    NoB = sum([ '.ppm' in s for s in os.listdir(f'{directory}/images/capture')])
     steps = np.arange(0,NoB*10,10) #vector with all the steps at which an image is taken
     cube = []
     for step in steps: #load bands into data structure
-        cube.append(np.rot90(cv.imread(f'{directory}images/capture/step{step}.ppm',cv.IMREAD_ANYDEPTH)))
+        cube.append(np.rot90(cv.imread(f'{directory}/images/capture/step{step}.ppm',cv.IMREAD_ANYDEPTH)))
     cube = np.array(cube, dtype = 'float64')
     cube = np.moveaxis(cube, 0, 2) #Rearranges the array to required shape
     return cube
@@ -162,9 +163,15 @@ def array2rgb(data_cube, three_layers):
 #This function calculates and applies a NUC to the entire datacube. The NUC is
 #dependent on the sensor temperature and the GSK settings of the camera. The
 #NUC is calculated from camera specific calibration files from the accompanying NUC directory
-def apply_NUC_cube(cube, sensor_temp, GSK, NUC_directory = '/home/mads/git/thermal-camera-src/src/python3-scripts/hsti python module/hsti-analysis/HSTI/data_files/NUC/10_10_200_191/'):
-    offset_coefs = np.load(f'{NUC_directory}offset_coefs_1st_order.npy', allow_pickle = True)
-    slope_coefs = np.load(f'{NUC_directory}slope_coefs_1st_order.npy', allow_pickle = True)
+def apply_NUC_cube(cube, sensor_temp, GSK, camera_ID = '10_10_200_191'):
+
+    resource_package = __name__
+    resource_path_offset = '/'.join(('HSTI_data_files-main', f"NUC/{camera_ID}/offset_coefs_1st_order.npy"))  # Do not use os.path.join()
+    resource_path_slope = '/'.join(('HSTI_data_files-main', f"NUC/{camera_ID}/slope_coefs_1st_order.npy"))  # Do not use os.path.join()
+    path_offset = pkg_resources.resource_stream(resource_package, resource_path_offset)
+    path_slope = pkg_resources.resource_stream(resource_package, resource_path_slope)
+    offset_coefs = np.load(path_offset, allow_pickle = True)
+    slope_coefs = np.load(path_slope, allow_pickle = True)
 
     M = np.array([[GSK, sensor_temp, 1]]).T
 
@@ -188,9 +195,16 @@ def apply_NUC_cube(cube, sensor_temp, GSK, NUC_directory = '/home/mads/git/therm
 #This function calculates and applies a NUC to a single image. The NUC is dependent
 #on the sensor temperature and the GSK settings of the camera. The NUC is
 #calculated from camera specific calibration files from the accompanying NUC directory.
-def apply_NUC_image(image, sensor_temp, GSK, NUC_directory = '/home/mads/git/thermal-camera-src/src/python3-scripts/hsti python module/hsti-analysis/HSTI/data_files/NUC/10_10_200_191/'):
-    offset_coefs = np.load(f'{NUC_directory}offset_coefs_1st_order.npy', allow_pickle = True)
-    slope_coefs = np.load(f'{NUC_directory}slope_coefs_1st_order.npy', allow_pickle = True)
+def apply_NUC_image(image, sensor_temp, GSK, camera_ID = '10_10_200_191'):
+
+    resource_package = __name__
+    resource_path_offset = '/'.join(('HSTI_data_files-main', f"NUC/{camera_ID}/offset_coefs_1st_order.npy"))  # Do not use os.path.join()
+    resource_path_slope = '/'.join(('HSTI_data_files-main', f"NUC/{camera_ID}/slope_coefs_1st_order.npy"))  # Do not use os.path.join()
+    path_offset = pkg_resources.resource_stream(resource_package, resource_path_offset)
+    path_slope = pkg_resources.resource_stream(resource_package, resource_path_slope)
+    offset_coefs = np.load(path_offset, allow_pickle = True)
+    slope_coefs = np.load(path_slope, allow_pickle = True)
+
 
     M = np.array([[GSK, sensor_temp, 1]]).T
 
@@ -207,3 +221,35 @@ def apply_NUC_image(image, sensor_temp, GSK, NUC_directory = '/home/mads/git/the
     slope_matrix = slope_correction.reshape([image.shape[0], image.shape[1]], order = 'C')
 
     return image  + image*slope_matrix + offset_matrix
+
+def naive_temperature_image(image, sensor_temp, GSK, camera_ID = '10_10_200_191'):
+    resource_package = __name__
+    resource_path_offset = '/'.join(('HSTI_data_files-main', f"Temperature_conversions/{camera_ID}/temp_offset_coefs_1st_order.npy"))  # Do not use os.path.join()
+    resource_path_slope = '/'.join(('HSTI_data_files-main', f"Temperature_conversions/{camera_ID}/temp_slope_coefs_1st_order.npy"))  # Do not use os.path.join()
+    path_offset = pkg_resources.resource_stream(resource_package, resource_path_offset)
+    path_slope = pkg_resources.resource_stream(resource_package, resource_path_slope)
+    offset_coefs = np.load(path_offset, allow_pickle = True)
+    slope_coefs = np.load(path_slope, allow_pickle = True)
+
+    a = slope_coefs[:,0]*GSK + slope_coefs[:,1]*sensor_temp + slope_coefs[:,2]
+    b = offset_coefs[:,0]*GSK + offset_coefs[:,1]*sensor_temp + offset_coefs[:,2]
+
+    flat_img = np.reshape(image, image.size)
+    flat_img = flat_img*a + b
+    return np.reshape(flat_img, [image.shape[0], image.shape[1]])
+
+def naive_temperature_cube(data_cube, sensor_temp, GSK, camera_ID = '10_10_200_191'):
+    resource_package = __name__
+    resource_path_offset = '/'.join(('HSTI_data_files-main', f"Temperature_conversions/{camera_ID}/temp_offset_coefs_1st_order.npy"))  # Do not use os.path.join()
+    resource_path_slope = '/'.join(('HSTI_data_files-main', f"Temperature_conversions/{camera_ID}/temp_slope_coefs_1st_order.npy"))  # Do not use os.path.join()
+    path_offset = pkg_resources.resource_stream(resource_package, resource_path_offset)
+    path_slope = pkg_resources.resource_stream(resource_package, resource_path_slope)
+    offset_coefs = np.load(path_offset, allow_pickle = True)
+    slope_coefs = np.load(path_slope, allow_pickle = True)
+
+    a = slope_coefs[:,0]*GSK + slope_coefs[:,1]*sensor_temp + slope_coefs[:,2]
+    b = offset_coefs[:,0]*GSK + offset_coefs[:,1]*sensor_temp + offset_coefs[:,2]
+
+    flat_cube = np.reshape(data_cube, [data_cube.shape[0]*data_cube.shape[1], data_cube.shape[2]])
+    flat_cube = flat_cube*a[:,np.newaxis] + b[:,np.newaxis]
+    return np.reshape(flat_cube, [data_cube.shape[0], data_cube.shape[1], data_cube.shape[2]])
