@@ -9,7 +9,7 @@ def remove_vignette(img_cube):
     #This function can both be used on single images as well as entire cubes
 
     resource_package = __name__
-    resource_path = '/'.join(('data_files', 'vignetting_profile.txt'))  # Do not use os.path.join()
+    resource_path = '/'.join(('HSTI_data_files-main', 'vignetting_profile.txt'))  # Do not use os.path.join()
     path = pkg_resources.resource_stream(resource_package, resource_path)
     vignette = np.loadtxt(path)
 
